@@ -91,7 +91,7 @@ class Axis(object):
         self.write_int32(address, value)
 
     def write_coil(self, address, value):
-        self._client.write_coil(address, value)
+        self._client.write_coil(address, value, unit=self._slave_id)
 
     def trig_coil(self, address):
         self.write_coil(address, False)
@@ -190,6 +190,10 @@ class Axis(object):
         self.write_coil(const.IO_IN_ERROR_RESET, 0)
         self.write_coil(const.IO_IN_ERROR_RESET, 1)
 
+    def reset_force(self):
+        self.write_coil(const.IO_IN_FORCE_RESET, 0)
+        self.write_coil(const.IO_IN_FORCE_RESET, 1)
+
     def set_servo_on_off(self, on_off):
         self.write_coil(const.IO_IN_SERVO, on_off)
 
